#app.py
# -*- coding: utf-8 -*-

#
# Copyright (C) 2015-2022 Rodrigo Ramírez Norambuena <a@rodrigoramirez.com>
#

from flask import Flask, jsonify, redirect, request, session, url_for, g, abort, send_from_directory, send_file
from flask_themes import setup_themes, render_theme_template
from werkzeug.serving import run_simple
from werkzeug.middleware.dispatcher import DispatcherMiddleware
from werkzeug.exceptions import abort
import logging
from flask_sqlalchemy import SQLAlchemy
#from qpanel import app
from flask import flash
from flask_babel import Babel, gettext
#from flask_script import manager
import flask_login
import requests
import os
from jinja2 import Environment


from qpanel import upgrader, job, rq_worker
import qpanel.utils as uqpanel


from qpanel.login import LoginForm

from qpanel.config import QPanelConfig
if QPanelConfig().has_queuelog_config():
    from qpanel.model import queuelog_data_queue

#db imports
from flask_wtf import FlaskForm
from wtforms import StringField, PasswordField, SubmitField, IntegerField, SelectField
from wtforms.validators import DataRequired, Length, Email, EqualTo
from flask_migrate import Migrate
from werkzeug.security import check_password_hash, generate_password_hash
from flask_wtf.csrf import CSRFProtect
from sqlalchemy.orm.session import make_transient
from sqlalchemy.orm import aliased
from urllib.parse import urlparse
from sqlalchemy import ForeignKey
from functools import wraps
import json
import requests




# app.py
get_data_queues1 = '{"708": {"members": {"hint:1227@ext-local": {"Name": "Sandura Shumba", "StateInterface": "hint:1227@ext-local", "Membership": "dynamic", "Penalty": "0", "CallsTaken": "0", "LastCall": "0", "LastPause": "0", "InCall": "0", "Status": "5", "Paused": "0", "PausedReason": "", "LastCallAgo": "0 seconds", "LastPauseAgo": "0 seconds"}}, "entries": {}}, "709": {"members": {}, "entries": {}}}'

# Convert the string to a dictionary
get_data_queues = json.loads(get_data_queues1)
app = Flask(__name__)
env = Environment()
port = "5432"
table_name = "queuelog"
#Add DataBase

app.secret_key = b'_5#y2L"F4Q8z\n\xec]/'

app.config['SQLALCHEMY_DATABASE_URI'] = 'postgresql://devopsuser:devops@localhost/users'
csrf = CSRFProtect(app)
app.config['CSRF_ENABLED'] = True
#Secret key
app.config['SECRET_KEY']='my super secret key'
#Initialize the Database
db = SQLAlchemy(app)
migrate = Migrate(app, db)
#create Model for users table
class pbxUser(db.Model):
    __tablename__ = 'pbx_user'

    id = db.Column(db.Integer, primary_key=True)
    name = db.Column(db.String(120), nullable=False)
    email = db.Column(db.String(120), unique=True, nullable=False)
    password = db.Column(db.String(60), nullable=False)
    accesslevel = db.Column(db.Integer, default=1)

    # Define the relationship with PBXUserConnection

    def set_password(self, password):
        self.password = generate_password_hash(password, method='sha256')

    def check_password(self, password):
        # Log the hashed password for debugging
        app.logger.debug("Stored Password Hash: %s", self.password)

        # Compare plaintext password with stored password
        return self.password == password


    #Create a string
    def __repr__(self):
        return '<Name %r>' % self.name
class LoginForm(FlaskForm):
    email = StringField(label='Email', validators=[DataRequired(), Email()])
    password = PasswordField(label='Password', validators=[DataRequired(), Length(min=6, max=16)])
    submit = SubmitField(label='Login')

class RegisterForm(FlaskForm):
    username = StringField(label='Username', validators=[DataRequired(), Length(min=3, max=20)])
    email = StringField(label='Email', validators=[DataRequired(), Email()])
    password = PasswordField(label='Password', validators=[DataRequired(), Length(min=6, max=16)])
    confirm_password = PasswordField(label='Confirm Password', validators=[DataRequired(), EqualTo('password')])
    selected_manager = StringField(label='Select Manager', validators=[DataRequired()])
    submit = SubmitField(label='Sign Up')


def make_set(value):
    return set(value)

app.jinja_env.filters['set'] = make_set
class User(flask_login.UserMixin):
    pass


cfg = QPanelConfig()

EXTERNAL_LOGIN = cfg.get_value_set_default('general', 'external_login', False) != False


def login_required(f):
    @wraps(f)
    def decorated_function(*args, **kwargs):
        if 'user_id' not in session:
            return redirect(url_for('login'))
        return f(*args, **kwargs)

    return decorated_function

def get_user_config_by_name(username):
    try:
        user = User()
        user.id = username
        user.password = cfg.get('users', username)
        return user
    except BaseException:
        return None


# Flask env
APPLICATION_ROOT = cfg.base_url
app.config.from_object(__name__)
babel = Babel(app)
app.config['BABEL_DEFAULT_LOCALE'] = cfg.language
app.secret_key = cfg.secret_key
setup_themes(app, app_identifier='qpanel')

db = SQLAlchemy(app)

login_manager = flask_login.LoginManager()
login_manager.init_app(app)


def render_template(template, **context):
    
    if cfg.theme == 'old':
        app.logger.warning(
            "The old theme is deprecated from 0.16.0 and "
            "not keep maintained anymore."
            "In the future will be removed by completely")
    theme = session.get('theme', cfg.theme)
    return render_theme_template(theme, template, **context)



@login_manager.request_loader
def request_loader(request):
    username = request.form.get('username')
    user_config = get_user_config_by_name(username)

    if not cfg.has_users():
        # fake login
        user = User()
        user.id = 'withoutlogin'
        return user

    if user_config is None:
        return

    user = set_data_user(user_config)
    user.is_authenticated = user_config == request.form['pw']
    return user

@app.before_first_request
def setup_logging():
    # issue https://github.com/benoitc/gunicorn/issues/379
    if not app.debug:
        app.logger.addHandler(logging.StreamHandler())
        app.logger.setLevel(logging.INFO)


# Utilities helpers
@app.context_processor
def utility_processor():
    def str_status_agent(value):
        try:
            value = int(value)
        except:
            value = 0
        unavailable = [0, 4, 5]
        free = [1]
        in_call = [10]

        if value in unavailable:
            return gettext('unavailable')
        elif value in free:
            return gettext('free')
        elif value in in_call:
            return gettext('in call')
        else:
            return gettext('busy')
    return dict(str_status_agent=str_status_agent)

@app.context_processor
def utility_processor():
    def request_interval():
        return cfg.interval * 1000
    return dict(request_interval=request_interval)

@app.errorhandler(404)
def page_not_found(e):
    return render_template('404.html'), 404

@babel.localeselector
def get_locale():
    langs = ['en', 'es', 'de', 'pt_BR', 'ru']
    browser = request.accept_languages.best_match(langs)
    try:
        return session['language']
    except KeyError:
        session['language'] = browser
        return browser
    
@app.context_processor
def utility_processor():
    def check_upgrade():
        return cfg.check_upgrade
    return dict(check_upgrade=check_upgrade)

@app.context_processor
def utility_processor():
    def show_service_level():
        return cfg.show_service_level
    return dict(show_service_level=show_service_level)

@app.context_processor
def utility_processor():
    def has_users():
        return cfg.has_users()
    return dict(has_users=has_users)

@app.context_processor
def utility_processor():
    def clean_str_to_div_id(value):
        return uqpanel.clean_str_to_div_id(value)
    return dict(clean_str_to_div_id=clean_str_to_div_id)


@app.context_processor
def utility_processor():
    def config():
        return cfg
    return dict(config=config)

@app.context_processor
def utility_processor():
    def current_version():
        return upgrader.get_current_version()
    return dict(current_version=current_version)

@app.context_processor
def inject_total_paused_agents():
    total_paused_agents = getattr(g, 'total_paused_agents', 0)
    return dict(total_paused_agents=total_paused_agents)

# ---------------------
# ---- Routes ---------
# ---------------------
# home

@app.route('/home')
@flask_login.login_required
def home():


    form = LoginForm()
    users = session.get('user') 

    # Provide the path to your text file
    status_response = requests.get('http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=all_queues_status')
    agent_status_response = requests.get('http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=all_queues_agent_status&queue=All')



    x = status_response.text
    y = agent_status_response.text
    print('all_queue_status')
    print(x)
    print('all queues_agent_status')
    print(y)


    dicts1 = parse_data(x)
    dicts2 = parse_data(y)
    print("11111111111111111111111111111111111111111111111111111111111111111")
    print(dicts2)
    queue_numbers = get_queue_numbers(dicts2)
    session['queue_numbers'] = queue_numbers
    

    users = pbxUser.query.all()
    # Set the manager_data in the session
    queues = combine_dicts(dicts1, dicts2)


    # Update the template variable based on FreeSWITCH
    template = 'index.html'

    # Pass the total_paused_agents, selected_manager, and refresh_page to the template
    return render_template(template, queueData=queues, form=form, users=users, queue=queues)

@app.route('/index_data')
def get_queue_data():

    # Provide the path to your text file
    status_response = requests.get('http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=all_queues_status')
    agent_status_response = requests.get('http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=all_queues_agent_status&queue=All')

    x = status_response.text
    y = agent_status_response.text

    print(x)
    print(y)

    dicts1 = parse_data(x)
    dicts2 = parse_data(y)

    # Set the manager_data in the session
    queues = combine_dicts(dicts1, dicts2)
    print(queues)

    return jsonify(queues)

def combine_dicts(dicts1, dicts2):
    combined_dicts = []
    for dict1 in dicts1:
        for dict2 in dicts2:
            if isinstance(dict1, dict) and isinstance(dict2, dict) and dict1.get('Queue_Nr') == dict2.get('Queue_Nr'):
                combined_dict = dict1.copy()
                combined_dict.update(dict2)
                combined_dicts.append(combined_dict)
                break  # Stop searching for matching Queue_Nr once found
    return combined_dicts

def get_queue_numbers(dict):
    queue_numbers = [item['Queue_Nr'] for item in dict]
    return queue_numbers

def parse_data(data_str):
    data_list = data_str.split('}{')
    if len(data_list) > 1:
        data_list = [d + '}' if i == 0 else '{' + d if i == len(data_list) - 1 else '{' + d + '}' for i, d in enumerate(data_list)]
    else:
        data_list = [data_str]
    
    result = []
    for data_item in data_list:
        # Remove extra characters at the beginning and end of the string
        data_item = data_item.strip('{}')
        # Split the string into key-value pairs
        pairs = data_item.split(',')
        item_dict = {}
        for pair in pairs:
            # Split each pair at the first colon to handle cases where there might be more than one colon in the value
            key, value = pair.split(':', 1)
            item_dict[key.strip('"')] = value.strip('"')
        result.append(item_dict)
    return result


def combine_status(name):
    # Provide the path to your text file
    urls = {
        'Paused': f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=queue_agent_status&option=Paused&queue={name}',
        'Free': f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=queue_agent_status&option=Free&queue={name}',
        'InCall': f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=queue_agent_status&option=InCall&queue={name}'
        # unavailable_url = f'https://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=queue_agent_status&option=Unavailable&queue={name}'
    }

    combined_data = []

    # Fetch data for each status and parse it into dictionaries, then append to combined_data
    for url in urls.values():
        response = requests.get(url)
        if response.status_code == 200:
            data_str = response.text
            parsed_data = parse_data(data_str)
            combined_data.extend(parsed_data)
            print(parsed_data)

    return combined_data


def combine_status2(name):
    # Provide the path to your text file
    urls = {
        'Paused': f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=queue_agent_status&option=Paused&queue={name}',
        'Free': f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=queue_agent_status&option=Free&queue={name}',
        'InCall': f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=queue_agent_status&option=InCall&queue={name}'
        # unavailable_url = f'https://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=queue_agent_status&option=Unavailable&queue={name}'
    }

    combined_data = []

    # Fetch data for each status and parse it into dictionaries, then append to combined_data
    for url in urls.values():
        response = requests.get(url)
        if response.status_code == 200:
            data_str = response.text
            parsed_data = parse_data(data_str)
            combined_data.extend(parsed_data)
    return combined_data

@app.route('/mainchart')
@flask_login.login_required
def mainchart(name=None):
        name = 'All'


        # Provide the path to your text file
        status_url = f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=all_queues_status'
        agent_status_url = f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=all_queues_agent_status&queue={name}'

        status_response = requests.get(status_url)
        agent_status_response = requests.get(agent_status_url)

        x = status_response.text
        y = agent_status_response.text
        print('xxxxxxxxxxxxxxxxxxxx')
        print('yyyyyyyyyyyyyyyyyyyy')


        dicts1 = parse_data(x)
        dicts2 = parse_data(y)

        queues = combine_dicts(dicts1, dicts2)
        print(queues)
        return jsonify( queue=queues, name=name)


@app.route('/', methods=['POST', 'GET'])
def login():
    print("Login route accessed")
    form = LoginForm()

    if form.validate_on_submit():
        input_email = form.email.data
        input_password = form.password.data
        print('Form data:', input_email, input_password)


        # Query the database for the user with the provided email
        user = pbxUser.query.filter_by(email=input_email).first()

        if user:
            if user.check_password(input_password):
                # Successful login
                flash('Login successful!', category='success')
                app.logger.info("User %s successfully logged in.", input_email)
                print("Login success")

                # Store user ID in the session
                session['user_id'] = user.id
                session['email'] = user.email
                return redirect('/home')
        else:
            # User not found
            flash('User not found. Please check your email.', category='error')
            app.logger.warning("User not found for email %s.", input_email)
            print("User not found")
            return redirect('/home')

    print('Form errors:', form.errors)
    return render_template('login.html', title='Login', form=form)

@app.route('/register', methods=['POST', 'GET'])
@flask_login.login_required
def register():
    name = None
    form = RegisterForm()
    our_users = pbxUser.query.order_by(pbxUser.email).all()
    user = None

    print(our_users)
    print('something')

    if form.validate_on_submit():
        print("Form is valid!")
        user = pbxUser.query.filter_by(email=form.email.data).first()

        if user is None:
            # Use form.name.data instead of form.username.data
            user = pbxUser(name=form.username.data, email=form.email.data, password=form.password.data, accesslevel=1)
            db.session.add(user)
            db.session.flush()  # Flush the session to get the user_id
            user_id = user.id

            try:
                db.session.commit()
                print("User added successfully.")
                return redirect(url_for('home'))
            except Exception as e:
                print(f"Error committing changes to the database: {str(e)}")
                db.session.rollback()
            flash("User added successfully.")
            name = form.username.data
            form.username.data = ''
            form.email.data = ''
            flash("User Added Successfully")
            our_users = pbxUser.query.order_by(pbxUser.email).all()
        return redirect(url_for('home'))

@app.route('/delete_user', methods=['POST'])
@flask_login.login_required
def delete_user():
    form = RegisterForm()
    user_id_to_delete = int(request.form.get('selectUser'))

    try:
        # Load the user into the session explicitly
        user_to_delete = pbxUser.query.get(user_id_to_delete)

        if user_to_delete:
            # Retrieve all PBXUserConnection records associated with the user

            # Print statements for debugging
            print(f"User to delete: {user_to_delete}")
            print("User deleted successfully")

            return redirect(url_for('home'))
        else:
            return render_template('index.html', error_message='User not found', form=form)
    except Exception as e:
        # Print the exception for debugging
        print(f"Error deleting user: {e}")
        return render_template('index.html', error_message='Error deleting user', form=form)

@app.route('/edit_user', methods=['POST'])
@flask_login.login_required # Ensure that the user is logged in to access this route
def edit_user():
    # Assuming you have a proper form validation (replace 'YourForm' with the actual form class)
    form = RegisterForm(request.form)

    # Get the data from the form
    user_id_to_edit = int(request.form.get('selected_user'))
    new_name = request.form.get('usernamename')  # corrected field name
    new_email = request.form.get('email')         # corrected field name
    new_password = request.form.get('password')
    new_access_level = request.form.get('access_level')  # Add this line

    print(f"{user_id_to_edit}")
    print(f"{new_name}")
    print(f"{new_email}")
    print(f"{new_password}")
    print(f"{new_access_level}")  # Add this line

    # Retrieve the user to be edited from the database
    user_to_edit = pbxUser.query.get(user_id_to_edit)
    print(f"attempting to update {user_to_edit}")

    if user_to_edit:
        # Update the user data if the fields are not empty
        if new_name != '':
            user_to_edit.name = new_name
        if new_email != '':
            user_to_edit.email = new_email
        if new_password != '':
            user_to_edit.set_password(new_password)
        if new_access_level != '':
            user_to_edit.accesslevel = int(new_access_level)

        # Commit the changes to the database
        try:
            db.session.commit()
            print("Commit successful")
        except Exception as e:
            print(f"Error during commit: {e}")
            db.session.rollback()


        # Redirect to the home page or wherever appropriate
        return redirect(url_for('home'))
    else:
        # If the user is not found or current user doesn't have the proper access level,
        # handle the error (you may customize this part)
        return render_template('404.html', error_message='User not found or insufficient access level', form=form)


@app.route('/get_updated_data')
def get_updated_data():

    global_url = f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=overview_agent_status'

    global_response = requests.get(global_url)

    x = global_response.text
    data = parse_data(x)
    # Fetch updated data here (replace with your actual data retrieval logic)
    print(x)
    return jsonify(data)


@app.route('/queue/<name>')
@flask_login.login_required
def queue(name=None):
        print(name)
        session['queue_name'] = name
        rr = combine_status(name)
        caller_url = f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=queue_callers_waiting&queue={name}'
        callers_response = requests.get(caller_url)
        callers =  callers_response.text
        callers_dict = parse_data(callers)

        form = LoginForm()

        path2 = '/qpanel/sassa/qpanel/static/queue101_incomming.json'
        # Read the content of the text file
        with open(path2, 'r') as file:
            content2 = file.read()
        # Convert the JSON string to a Python dictionary
        callers = json.loads(content2)


        # Provide the path to your text file
        status_url = f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=all_queues_status'
        agent_status_url = f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=all_queues_agent_status&queue={name}'

        status_response = requests.get(status_url)
        agent_status_response = requests.get(agent_status_url)

        x = status_response.text
        y = agent_status_response.text
        print('xxxxxxxxxxxxxxxxxxxx')
        print(x)
        print('yyyyyyyyyyyyyyyyyyyy')
        print(y)

        dicts1 = parse_data(x)
        dicts2 = parse_data(y)

        queues = combine_dicts(dicts1, dicts2)

        template = 'queue.html'
        return render_template(template, agents=rr, callers=callers_dict, queue=queue, form=form, name=name)


@app.route('/get_dashboard_data')
def get_dashboard_data():
    # Code to fetch and process dashboard data
    data1 = get_data_queues
        # Call filter_agents function and unpack the returned values
    filtered_agents, paused_count, unique_state_interfaces_count, unique_state_interfaces, all_incoming_calls = filter_agents(data1)
    # Your data object
    return jsonify(filtered_agents)


@app.route('/queue/<name>.json')
@flask_login.login_required
def queue_json(name=None):
        
        name = session['queue_name']
        rr = combine_status2(name)
        print('name')
        print(name)
        caller_url = f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=queue_callers_waiting&queue={name}'
        callers_response = requests.get(caller_url)
        callers =  callers_response.text
        callers_dict = parse_data(callers)

        path2 = '/qpanel/sassa/qpanel/static/queue101_incomming_test.json'
        # Read the content of the text file
        with open(path2, 'r') as file:
            content2 = file.read()
        # Convert the JSON string to a Python dictionary
        callers = json.loads(content2)

        # Provide the path to your text file
        status_url = f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=all_queues_status'
        agent_status_url = f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=all_queues_agent_status&queue={name}'

        status_response = requests.get(status_url)
        agent_status_response = requests.get(agent_status_url)

        x = status_response.text
        y = agent_status_response.text

        dicts1 = parse_data(x)
        dicts2 = parse_data(y)

        queues = combine_dicts(dicts1, dicts2)
        print(queues)
        return jsonify(agents=rr, callers=callers_dict, queue=queues, name=name)

@app.route('/queuegiven')
@flask_login.login_required
def queue_given(name=None):
        name = session['queue_name']
        rr = combine_status(name)


        # Provide the path to your text file
        status_url = f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=all_queues_status'
        agent_status_url = f'http://sassa.voiceflow.co.za/api.php?secret=9hHwZmOFaYGfQH9Ya1R5y47imD0itlOj&function=all_queues_agent_status&queue={name}'

        status_response = requests.get(status_url)
        agent_status_response = requests.get(agent_status_url)

        x = status_response.text
        y = agent_status_response.text
        print('xxxxxxxxxxxxxxxxxxxx')
        print('yyyyyyyyyyyyyyyyyyyy')


        dicts1 = parse_data(x)
        dicts2 = parse_data(y)

        queues = combine_dicts(dicts1, dicts2)
        print(queues)
        return jsonify(agents=rr, queue=queues, name=name)

def combine_dicts2(dicts1, dicts2):
    combined_dicts = []
    for dict1 in dicts1:
        for dict2 in dicts2:
            if isinstance(dict1, dict) and isinstance(dict2, dict) and dict1.get('Queue_Nr') == dict2.get('Queue_Nr'):
                combined_dict = dict1.copy()
                combined_dict.update(dict2)
                combined_dicts.append(combined_dict)
                break  # Stop searching for matching Queue_Nr once found
    return combined_dicts


# data queue

@app.route('/queues')
@flask_login.login_required
def queues():
        # Provide the path to your text file
        path = '/qpanel/sassa/qpanel/static/index_queues.txt.txt'
        # Read the content of the text file
        with open(path, 'r') as file:
            content = file.read()

        data = get_data_queues
        data1, paused_count, unique_state_interfaces_count, unique_state_interfaces, all_incoming_calls = filter_agents(data)
        return jsonify(data=content)


@app.route('/dashboard')
def dashboard():
    return render_template('index_chart.html')

@app.route('/lang')
@app.route('/lang/<language>')
@flask_login.login_required
def language(language=None):
    session['language'] = language
    return redirect(url_for('home'))

@app.route('/check_new_version')
@flask_login.login_required
def check_new_version():
    need_upgrade = False
    try:
        if upgrader.require_upgrade():
            need_upgrade = False
    except:
        pass

    return jsonify(
        require_upgrade=need_upgrade,
        current_version=upgrader.get_current_version(),
        last_stable_version=upgrader.get_stable_version()
    )

@app.route('/get_text_file')
def get_text_file():
    # Provide the path to your text file
    path = 'static/index_queues.txt.txt'
    # Use Flask's send_file function to send the file
    return send_file(path, as_attachment=True)

@app.route('/view_text_file_json')
def view_text_file_json():
    # Provide the path to your text file
    path = '/qpanel/sassa/qpanel/static/index_queues.txt.txt'
    # Read the content of the text file
    with open(path, 'r') as file:
        content = file.read()
    # Return the content as JSON data
    return jsonify({'content': content})

@app.route('/logout')
def logout():
    flask_login.logout_user()
    return redirect(url_for('login'))


@app.route('/favicon.ico')
def favicon():
    return send_from_directory(os.path.join(app.root_path, 'static'),
                               'favicon.ico', mimetype='image/vnd.microsoft.icon')

# ---------------------
# ---- Main  ----------
# ---------------------
def main():

    # Set reloader to False, bug present for imports
    # Retain this as FIXME
    # https://github.com/mitsuhiko/flask/issues/1246
    reloader = False

    if cfg.is_debug:
        app.config['DEBUG'] = True
        uqpanel.add_debug_toolbar(app)

    if cfg.queues_for_reset_stats():
        if job.check_connect_redis():
            rq_worker.start_jobs()
        else:
            print("Error: There not connection to Redis")
            print("       Reset stats will not work\n")

    if cfg.base_url == '/':
        app.run(host=cfg.host_bind, port=cfg.port_bind, use_reloader=reloader,
                extra_files=[cfg.path_config_file])
    else:
        application = DispatcherMiddleware(Flask('dummy_app'), {
            app.config['APPLICATION_ROOT']: app,
        })
        run_simple(cfg.host_bind, cfg.port_bind, application,
                   use_reloader=reloader, extra_files=[cfg.path_config_file])



if __name__ == '__main__':

    main()
